July 3, 2013
3:47 p.m.
Hello to all, and thanks for the great work on PyPy. There remains a very problematic case in PyPy, where PyPy (tested with nightly) is around 193 times slower than CPython. This happens when reading a file using the universal newline flag ("rU"). Are there any plans to fix this problematic case, or should we just avoid using it when running under PyPy? Kind regards, lefteris.